# blueye.legacyprotocol

This package contains the legacy protocol definitions for Blueye drones. It was deprecated with Blunux 3.0 and is no longer supported. The new protocol is based on Protobuf messages passed over a ZeroMQ layer.
